==> chezmoi-2.7.4.tar.gz: chezmoi-2.7.4/internal/cmd/chattrcmd_test.go <==
package cmd

import (
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
)

func TestParseAttrModifier(t *testing.T) {
	for _, tc := range []struct {
		s           string
		expected    *attrModifier
		expectedErr bool
	}{
		{
			s: "empty",
			expected: &attrModifier{
				empty: boolModifierSet,
			},
		},
		{
			s: "+empty",
			expected: &attrModifier{
				empty: boolModifierSet,
			},
		},
		{
			s: "-empty",
			expected: &attrModifier{
				empty: boolModifierClear,
			},
		},
		{
			s: "noempty",
			expected: &attrModifier{
				empty: boolModifierClear,
			},
		},
		{
			s: "e",
			expected: &attrModifier{
				empty: boolModifierSet,
			},
		},
		{
			s: "encrypted",
			expected: &attrModifier{
				encrypted: boolModifierSet,
			},
		},
		{
			s: "executable",
			expected: &attrModifier{
				executable: boolModifierSet,
			},
		},
		{
			s: "x",
			expected: &attrModifier{
				executable: boolModifierSet,
			},
		},
		{
			s: "b",
			expected: &attrModifier{
				order: orderModifierSetBefore,
			},
		},
		{
			s: "-b",
			expected: &attrModifier{
				order: orderModifierClearBefore,
			},
		},
		{
			s: "after",
			expected: &attrModifier{
				order: orderModifierSetAfter,
			},
		},
		{
			s: "noafter",
			expected: &attrModifier{
				order: orderModifierClearAfter,
			},
		},
		{
			s: "once",
			expected: &attrModifier{
				condition: conditionModifierSetOnce,
			},
		},
		{
			s: "private",
			expected: &attrModifier{
				private: boolModifierSet,
			},
		},
		{
			s: "p",
			expected: &attrModifier{
				private: boolModifierSet,
			},
		},
		{
			s: "template",
			expected: &attrModifier{
				template: boolModifierSet,
			},
		},
		{
			s: "t",
			expected: &attrModifier{
				template: boolModifierSet,
			},
		},
		{
			s: "empty,+executable,noprivate,-t",
			expected: &attrModifier{
				empty:      boolModifierSet,
				executable: boolModifierSet,
				private:    boolModifierClear,
				template:   boolModifierClear,
			},
		},
		{
			s: " empty , -private, notemplate ",
			expected: &attrModifier{
				empty:    boolModifierSet,
				private:  boolModifierClear,
				template: boolModifierClear,
			},
		},
		{
			s: "p,,-t",
			expected: &attrModifier{
				private:  boolModifierSet,
				template: boolModifierClear,
			},
		},
		{
			s:           "unknown",
			expectedErr: true,
		},
	} {
		t.Run(tc.s, func(t *testing.T) {
			actual, err := parseAttrModifier(tc.s)
			if tc.expectedErr {
				require.Error(t, err)
			} else {
				require.NoError(t, err)
				assert.Equal(t, tc.expected, actual)
			}
		})
	}
}

==> chezmoi-2.9.2.tar.gz: chezmoi-2.9.2/internal/cmd/chattrcmd_test.go <==
package cmd

import (
	"testing"

	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
)

func TestParseAttrModifier(t *testing.T) {
	for _, tc := range []struct {
		s           string
		expected    *modifier
		expectedErr bool
	}{
		{
			s: "empty",
			expected: &modifier{
				empty: boolModifierSet,
			},
		},
		{
			s: "+empty",
			expected: &modifier{
				empty: boolModifierSet,
			},
		},
		{
			s: "-empty",
			expected: &modifier{
				empty: boolModifierClear,
			},
		},
		{
			s: "noempty",
			expected: &modifier{
				empty: boolModifierClear,
			},
		},
		{
			s: "e",
			expected: &modifier{
				empty: boolModifierSet,
			},
		},
		{
			s: "encrypted",
			expected: &modifier{
				encrypted: boolModifierSet,
			},
		},
		{
			s: "executable",
			expected: &modifier{
				executable: boolModifierSet,
			},
		},
		{
			s: "x",
			expected: &modifier{
				executable: boolModifierSet,
			},
		},
		{
			s: "b",
			expected: &modifier{
				order: orderModifierSetBefore,
			},
		},
		{
			s: "-b",
			expected: &modifier{
				order: orderModifierClearBefore,
			},
		},
		{
			s: "after",
			expected: &modifier{
				order: orderModifierSetAfter,
			},
		},
		{
			s: "noafter",
			expected: &modifier{
				order: orderModifierClearAfter,
			},
		},
		{
			s: "once",
			expected: &modifier{
				condition: conditionModifierSetOnce,
			},
		},
		{
			s: "private",
			expected: &modifier{
				private: boolModifierSet,
			},
		},
		{
			s: "p",
			expected: &modifier{
				private: boolModifierSet,
			},
		},
		{
			s: "template",
			expected: &modifier{
				template: boolModifierSet,
			},
		},
		{
			s: "t",
			expected: &modifier{
				template: boolModifierSet,
			},
		},
		{
			s: "create",
			expected: &modifier{
				sourceFileType: sourceFileTypeModifierSetCreate,
			},
		},
		{
			s: "-create",
			expected: &modifier{
				sourceFileType: sourceFileTypeModifierClearCreate,
			},
		},
		{
			s: "modify",
			expected: &modifier{
				sourceFileType: sourceFileTypeModifierSetModify,
			},
		},
		{
			s: "-script",
			expected: &modifier{
				sourceFileType: sourceFileTypeModifierClearScript,
			},
		},
		{
			s: "+symlink",
			expected: &modifier{
				sourceFileType: sourceFileTypeModifierSetSymlink,
			},
		},
		{
			s: "empty,+executable,noprivate,-t",
			expected: &modifier{
				empty:      boolModifierSet,
				executable: boolModifierSet,
				private:    boolModifierClear,
				template:   boolModifierClear,
			},
		},
		{
			s: " empty , -private, notemplate ",
			expected: &modifier{
				empty:    boolModifierSet,
				private:  boolModifierClear,
				template: boolModifierClear,
			},
		},
		{
			s: "p,,-t",
			expected: &modifier{
				private:  boolModifierSet,
				template: boolModifierClear,
			},
		},
		{
			s:           "unknown",
			expectedErr: true,
		},
	} {
		t.Run(tc.s, func(t *testing.T) {
			actual, err := parseModifier(tc.s)
			if tc.expectedErr {
				require.Error(t, err)
			} else {
				require.NoError(t, err)
				assert.Equal(t, tc.expected, actual)
			}
		})
	}
}
